@@ -29,6 +29,7 @@
 #include "manage_configs.h"
 #include "manage_events.h"
 #include "manage_get.h"
+#include "manage_tasks.h"
 #include "sql.h"
 #include "utils.h"
 
@@ -343,7 +344,6 @@ typedef resource_t group_t;
 typedef resource_t host_t;
 typedef resource_t tag_t;
 typedef resource_t target_t;
-typedef resource_t task_t;
 typedef resource_t ticket_t;
 typedef resource_t tls_certificate_t;
 typedef resource_t result_t;
@@ -523,109 +523,6 @@ set_resource_id_deprecated (const char *, const char *, gboolean);
  "Please contact your local system administrator if you think it\n"           \
  "was created or assigned erroneously.\n"
 
-int
-manage_check_alerts (GSList *, const db_conn_info_t *);
-
-int
-create_alert (const char*, const char*, const char*, const char*, event_t,
-              GPtrArray*, alert_condition_t, GPtrArray*, alert_method_t,
-              GPtrArray*, alert_t*);
-
-int
-copy_alert (const char*, const char*, const char*, alert_t*);
-
-int
-modify_alert (const char*, const char*, const char*, const char*,
-              const char*, event_t, GPtrArray*, alert_condition_t, GPtrArray*,
-              alert_method_t, GPtrArray*);
-
-int
-delete_alert (const char *, int);
-
-char *
-alert_uuid (alert_t);
-
-gboolean
-find_alert_with_permission (const char *, alert_t *, const char *);
-
-int
-manage_test_alert (const char *, gchar **);
-
-int
-alert_in_use (alert_t);
-
-int
-trash_alert_in_use (alert_t);
-
-int
-alert_writable (alert_t);
-
-int
-trash_alert_writable (alert_t);
-
-int
-alert_count (const get_data_t *);
-
-int
-init_alert_iterator (iterator_t*, get_data_t*);
-
-int
-alert_iterator_event (iterator_t*);
-
-int
-alert_iterator_condition (iterator_t*);
-
-int
-alert_iterator_method (iterator_t*);
-
-char *
-alert_iterator_filter_uuid (iterator_t*);
-
-char *
-alert_iterator_filter_name (iterator_t*);
-
-int
-alert_iterator_filter_trash (iterator_t*);
-
-int
-alert_iterator_filter_readable (iterator_t*);
-
-int
-alert_iterator_active (iterator_t*);
-
-alert_method_t
-alert_method (alert_t alert);
-
-void
-init_alert_data_iterator (iterator_t *, alert_t, int, const char *);
-
-const char*
-alert_data_iterator_name (iterator_t*);
-
-const char*
-alert_data_iterator_data (iterator_t*);
-
-void
-init_alert_task_iterator (iterator_t*, alert_t, int);
-
-const char*
-alert_task_iterator_name (iterator_t*);
-
-const char*
-alert_task_iterator_uuid (iterator_t*);
-
-int
-alert_task_iterator_readable (iterator_t*);
-
-void
-init_task_alert_iterator (iterator_t*, task_t);
-
-const char*
-task_alert_iterator_uuid (iterator_t*);
-
-const char*
-task_alert_iterator_name (iterator_t*);
-
 
 /* Task global variables and preprocessor variables. */
 
@@ -3314,9 +3211,15 @@ find_filter_with_permission (const char*, filter_t*, const char*);
 char*
 filter_uuid (filter_t);
 
+char*
+trash_filter_uuid (filter_t);
+
 char*
 filter_name (filter_t);
 
+char*
+trash_filter_name (filter_t);
+
 gchar*
 filter_term (const char *);
 
