@@ -24,6 +24,8 @@
  */
 
 #include "manage_events.h"
+#include "manage_sql_alerts.h"
+#include "manage_sql_events.h"
 #include "manage_acl.h"
 #include "manage_sql.h"
 #include "manage_sql_tickets.h"
@@ -34,6 +36,74 @@
  */
 #define G_LOG_DOMAIN "md manage"
 
+/**
+ * @brief Return the SecInfo count.
+ *
+ * @param[in]  alert      Alert.
+ * @param[in]  filter_id  Condition filter id.
+ *
+ * @return 1 if met, else 0.
+ */
+static time_t
+alert_secinfo_count (alert_t alert, char *filter_id)
+{
+  get_data_t get;
+  int db_count, uuid_was_null;
+  event_t event;
+  gboolean get_modified;
+  time_t feed_version_epoch;
+  char *secinfo_type;
+
+  event = alert_event (alert);
+  get_modified = (event == EVENT_UPDATED_SECINFO);
+
+  if (current_credentials.uuid == NULL)
+    {
+      current_credentials.uuid = alert_owner_uuid (alert);
+      uuid_was_null = 1;
+    }
+  else
+    uuid_was_null = 0;
+
+  memset (&get, '\0', sizeof (get));
+  if (filter_id && strlen (filter_id) && strcmp (filter_id, "0"))
+    get.filt_id = filter_id;
+
+  secinfo_type = alert_data (alert, "event", "secinfo_type");
+
+  if (strcmp (secinfo_type, "nvt") == 0)
+    {
+      feed_version_epoch = nvts_feed_version_epoch ();
+      db_count = nvt_info_count_after (&get,
+                                       feed_version_epoch,
+                                       get_modified);
+    }
+  else if (strcmp (secinfo_type, "cert_bund_adv") == 0
+           || strcmp (secinfo_type, "dfn_cert_adv") == 0)
+    {
+      feed_version_epoch = cert_check_time ();
+      db_count = secinfo_count_after (&get,
+                                      secinfo_type,
+                                      feed_version_epoch,
+                                      get_modified);
+    }
+  else // assume SCAP data
+    {
+      feed_version_epoch = scap_check_time ();
+      db_count = secinfo_count_after (&get,
+                                      secinfo_type,
+                                      feed_version_epoch,
+                                      get_modified);
+    }
+
+  if (uuid_was_null)
+    {
+      free (current_credentials.uuid);
+      current_credentials.uuid = NULL;
+    }
+
+  return db_count;
+}
 
 /**
  * @brief Return whether the condition of an alert is met by a task.
@@ -347,7 +417,7 @@ condition_met (task_t task, report_t report, alert_t alert,
 }
 
 /**
- * @brief Escalate an event with preset report filtering.
+ * @brief Trigger an event with preset report filtering.
  *
  * @param[in]  alert       Alert.
  * @param[in]  task        Task.
@@ -363,9 +433,10 @@ condition_met (task_t task, report_t report, alert_t alert,
  *         -5 alert script failed.
  */
 static int
-escalate_1 (alert_t alert, task_t task, report_t report, event_t event,
-            const void* event_data, alert_method_t method,
-            alert_condition_t condition, gchar **script_message)
+trigger_with_presets (alert_t alert, task_t task, report_t report,
+                      event_t event, const void* event_data,
+                      alert_method_t method, alert_condition_t condition,
+                      gchar **script_message)
 {
   int ret;
   get_data_t get;
@@ -388,8 +459,8 @@ escalate_1 (alert_t alert, task_t task, report_t report, event_t event,
                                     method == ALERT_METHOD_EMAIL ? 1000 : -1);
     }
 
-  ret = escalate_2 (alert, task, report, event, event_data, method, condition,
-                    &get, 1, 1, script_message);
+  ret = trigger (alert, task, report, event, event_data, method, condition,
+                 &get, 1, 1, script_message);
   free (results_filter);
   g_free (get.filter);
   return ret;
@@ -594,21 +665,21 @@ event (event_t event, void* event_data, resource_t resource_1,
 
       alert = g_array_index (alerts_triggered, alert_t, index);
       condition = alert_condition (alert);
-      escalate_1 (alert,
-                  resource_1,
-                  resource_2,
-                  event,
-                  event_data,
-                  alert_method (alert),
-                  condition,
-                  NULL);
+      trigger_with_presets (alert,
+                            resource_1,
+                            resource_2,
+                            event,
+                            event_data,
+                            alert_method (alert),
+                            condition,
+                            NULL);
     }
 
   g_array_free (alerts_triggered, TRUE);
 }
 
 /**
- * @brief Escalate an alert with task and event data.
+ * @brief Trigger an alert with task and event data.
  *
  * @param[in]  alert_id    Alert UUID.
  * @param[in]  task_id     Task UUID.
@@ -650,6 +721,6 @@ manage_alert (const char *alert_id, const char *task_id, event_t event,
 
   condition = alert_condition (alert);
   method = alert_method (alert);
-  return escalate_1 (alert, task, 0, event, event_data, method, condition,
-                     script_message);
+  return trigger_with_presets (alert, task, 0, event, event_data, method,
+                               condition, script_message);
 }
